# Pre-defined system atoms
sequence_pred = 'seq/P/.'
noun_connector_pred = '+/B/.'
lemma_pred = 'lemma/P/.'
coref_pred = 'coref/P/.'
main_coref_pred = 'main_coref/P/.'
type_of_pred = 'type_of/P/.'
is_pred = 'is/P/.'
possessive_builder = 'poss/Bp.am/.'
gender_pred = 'gender/P/.'
number_pred = 'number/P/.'
animacy_pred = 'animacy/P/.'

# Pre-defined entity keys
coref_set_id_key = 'coref'

# Logo
ascii_logo = """

                        _     _               _       
                       | |   | |             (_)      
   __ _ _ __ __ _ _ __ | |__ | |__  _ __ __ _ _ _ __  
  / _` | '__/ _` | '_ \| '_ \| '_ \| '__/ _` | | '_ \ 
 | (_| | | | (_| | |_) | | | | |_) | | | (_| | | | | |
  \__, |_|  \__,_| .__/|_| |_|_.__/|_|  \__,_|_|_| |_|
   __/ |         | |                                  
  |___/          |_|                                  

"""
